##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling objectives in SAP LeanIX.
  * SAP LeanIX is not an OKR or scorecard tool. Do not manage the progress status of OKRs or track organization performance over time in SAP LeanIX.
